eps0 = 8.854187818e-12 ;

Integration {
  { Name I1 ;
    Case { 
      { Type Gauss ;
        Case { 
	  { GeoElement Point       ; NumberOfPoints  1 ; }
	  { GeoElement Line        ; NumberOfPoints  3 ; }
	  { GeoElement Triangle    ; NumberOfPoints  4 ; }
	  { GeoElement Quadrangle  ; NumberOfPoints  4 ; }
	  { GeoElement Tetrahedron ; NumberOfPoints  4 ; }
	  { GeoElement Hexahedron  ; NumberOfPoints  6 ; }
	  { GeoElement Prism       ; NumberOfPoints  6 ; } 
	}
      }
    }
  }
  
  { Name GradGrad ;
    Case { {Type Gauss ;
            Case { { GeoElement Triangle    ; NumberOfPoints  4 ; }
                   { GeoElement Quadrangle  ; NumberOfPoints  4 ; }
                   { GeoElement Tetrahedron ; NumberOfPoints  4 ; }
                   { GeoElement Hexahedron  ; NumberOfPoints  6 ; }
                   { GeoElement Prism       ; NumberOfPoints  9 ; } }
           }
         }
  }
  { Name CurlCurl ;
    Case { {Type Gauss ;
            Case { { GeoElement Triangle    ; NumberOfPoints  4 ; }
                   { GeoElement Quadrangle  ; NumberOfPoints  4 ; }
                   { GeoElement Tetrahedron ; NumberOfPoints  4 ; }
                   { GeoElement Hexahedron  ; NumberOfPoints  6 ; }
                   { GeoElement Prism       ; NumberOfPoints  9 ; } }
           }
         }
  }
}

FunctionSpace {
  { Name Hgrad_T; Type Form0; 
    BasisFunction {
      { Name sn; NameOfCoef Tn; Function BF_Node; Support Vol_The; 
        Entity NodesOf[All]; }
    }
    Constraint {
      { NameOfCoef Tn; EntityType NodesOf ; NameOfConstraint Sta_T; }
     }
  }

}

FunctionSpace {
  { Name Hgrad_v ; Type Form0 ;
    BasisFunction {
      // v = v  s   ,  for all nodes
      //      n  n
      { Name sn ; NameOfCoef vn ; Function BF_Node ;
        Support Domain_Ele ; Entity NodesOf[ All ] ; }
    }
    Constraint {
      { NameOfCoef vn ; EntityType NodesOf ; 
        NameOfConstraint ElectricScalarPotential ; }
    }
  }
}

Function{
  DefineFunction[Flux,qVol,h,hr,TConv, sigma];
}
Group{
  DefineGroup[SurConv_The,SurRad_The,Vol_The,Domain_Ele];
}

Formulation {

  { Name The_T ; Type FemEquation; 
    Quantity { 
      { Name T;  Type Local; NameOfSpace Hgrad_T; }
      { Name v ; Type Local; NameOfSpace Hgrad_v; }
    }
    Equation {
    
      Galerkin { [sigma[] * Dof{d v} , {d v}] ; In Domain_Ele ; 
                 Jacobian JVol ; Integration GradGrad ;}
      		 
      Galerkin { [ k[] * Dof{d T} , {d T} ]; 
                 In Vol_The; Integration I1; Jacobian Vol;  }

      Galerkin { Dt [ rhoc[] * Dof{T} , {T} ]; 
                 In Vol_The; Integration I1; Jacobian Vol;  }

      Galerkin { [ -qVol[] , {T} ]; 
                 In Vol_The; Integration I1; Jacobian Vol;  }

      Galerkin { [ -(-{d v}*(sigma[] *  -{d v})) , {T} ]; // J * E
                   In Domain_Ele; Integration I1; Jacobian Vol;  }

      Galerkin { [ h[] * Dof{T} , {T} ] ; 
                   In SurConv_The ; Integration I1; Jacobian Sur;  }

      Galerkin { [ -h[] * TConv[] , {T} ] ;
                  In SurConv_The ; Integration I1; Jacobian Sur;  }
 
      Galerkin { [ hr[{T}] * (({T})^4-(TConv[])^4) , {T} ] ; 
                  In SurRad_The ; Integration I1; Jacobian Sur;  }   
    }
  }
}

Resolution {
  { Name linear_general;
    System {
      { Name T; NameOfFormulation The_T; }
    }
    Operation { 
      InitSolution T ; SaveSolution T ;
      TimeLoopTheta {
	Time0  t0 ; TimeMax t1 ; DTime dt ; Theta 1. ;
	Operation { 
	  Generate T ; Solve T ; 
	  Test[SaveFct[]] {SaveSolution T;} 
	} 
      } 
    }
  }

  { Name linear_fast;
    System {
      { Name T; NameOfFormulation The_T; }
    }
    Operation { 
      InitSolution T ;  SaveSolution T ;
      GenerateSeparate T ;
      TimeLoopTheta {
	Time0  t0 ; TimeMax t1 ; DTime dt ; Theta 1. ;
	Operation { 
	  Update[T,TimeFct[]] ; 
	  Solve T ; 
	  Test[SaveFct[]] {SaveSolution T;} 
	} 
      } 
    }
  }
  }


PostProcessing {
  { Name The; NameOfFormulation The_T;
    Quantity {
      { Name T; Value{ Local{ [ {T} ] ; In Vol_The; Jacobian Vol ; } } }      
      { Name v ; Value { Local { [ {v} ] ; In Domain_Ele ; Jacobian Vol ; } } }
      { Name j ; Value { Local { [ 1/sigma[] *  -{d v} ] ; In Domain_Ele ; Jacobian Vol ; } } }
    }
  }
  
}



